@@ -307,7 +307,7 @@ class CompilerRunner(object):
                     [(x if os.path.exists(x) else '-l'+x) for x in self.libraries] +
                     self.linkline)
         counted = []
-        for envvar in re.findall('\$\{(\w+)\}', ' '.join(cmd)):
+        for envvar in re.findall(r'\$\{(\w+)\}', ' '.join(cmd)):
             if os.getenv(envvar) is None:
                 if envvar not in counted:
                     counted.append(envvar)
